@@ -156,8 +156,6 @@ pub enum MigrationDirection {
 struct EdgeState {
   /// SQL script to transition the schema version
   schema: &'static str,
-  /// SQL script to populate data
-  data: Option<&'static str>,
 }
 
 #[derive(Debug)]
@@ -188,7 +186,7 @@ impl SchemaResolver {
           continue;
         };
         let schema = f.contents_utf8().unwrap();
-        let edge = EdgeState { schema, data: None };
+        let edge = EdgeState { schema };
         let state: SchemaState = caps[1].parse::<SchemaVersion>().unwrap().into();
         graph.add_node(state);
         assert!(states.insert(state, ()).is_none());
@@ -206,7 +204,7 @@ impl SchemaResolver {
           continue;
         };
         let schema = f.contents_utf8().unwrap();
-        let edge = EdgeState { schema, data: None };
+        let edge = EdgeState { schema };
         let start: SchemaState = caps[1].parse::<SchemaVersion>().unwrap().into();
         let end: SchemaState = caps[2].parse::<SchemaVersion>().unwrap().into();
         assert!(start < end);
